@@ -15,11 +15,11 @@ use Zim::Store;
 use Zim::History;
 use Zim::Page;
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 our @ISA = qw/Zim::Events/;
 
-our $COPYRIGHT = 'Copyright (c) 2005, 2007 Jaap G Karssenberg.';
+our $COPYRIGHT = 'Copyright (c) 2005, 2008 Jaap G Karssenberg.';
 our $LONG_VERSION = << "EOT";
 zim $VERSION - A desktop wiki and outliner
 
@@ -35,21 +35,42 @@ Please report bugs to pardus\@cpan.org
 EOT
 our $AUTHORS = 'Jaap Karssenberg <pardus@cpan.org>';
 our $TRANSLATORS = q{
+Andrés Rassol (es)
+Balaam's Miracle (nl)
 Daniel Stoyanov (fr)
 Etienne Le Belléguy (fr)
+Frederik 'Freso' S. Olesen (da)
+Frits Salomons (nl)
+Hokey (de)
 Jaap Karssenberg (nl)
 Jacopo Moronato (it)
 Javier Rovegno Campos (es)
+Jean DEMARTINI (fr)
+Jean Demartini (fr)
+Jeppe Toustrup (da)
 João Santos (pt)
+Juhana Uuttu (fi)
 Jérôme Guelfucci (fr)
 Klaus Vormweg (de)
+M. Emin Akşehirli (tr)
+Mathijs (nl)
 Matthias Mailänder (de)
 Mikael Mildén (sv)
+Nikolaus Klumpp (de)
+Nikolay A. Fetisov (ru)
 Nucleos (fr)
 Paco Molinero (es)
+René 'Necoro' Neumann (de)
+Roberto Suarez (gl)
 Rui Nibau (fr)
+Servilio Afre Puentes (es)
+Vladimir Sharshov (ru)
 Vlastimil Ott (cs)
 Yaron (he)
+marisma (gl)
+rainofchaos (zh_CN)
+sanya (ru)
+太和 (zh_CN)
 };
 our $WEBSITE = 'http://www.pardus.nl/projects/zim';
 
@@ -108,30 +129,62 @@ Constructor. Parameters can be:
 =cut
 
 sub new {
-	my ($class, %param) = @_;
+	my $class = shift;
 
-	$param{namespace} ||= ':';
-	$param{namespace} =~ s/:?$/:/;
-	die "BUG: store initialized without directory"
-		unless $param{dir};
-	$param{dir} = dir($param{dir}) unless ref($param{dir});
-	die "No such directory: $param{dir}\n" unless $param{dir}->exists;
-	
-	my $self = bless {%param}, $class;
-	$self->{config} ||= {};
+	my $self = bless {@_}, $class;
+	$$self{namespace} ||= ':';
+	$$self{namespace} =~ s/:?$/:/;
+
+	# Check notebook source
+	if ($$self{file}) {
+		my $file = file( delete $$self{file} );
+		die "No such file: $file\n" unless $file->exists;
+		$$self{dir} ||= $file->dir;
+		if ($file =~ /\.gjots$/) {
+			$self->add_child(':', 'Gjots', file => $file);
+			$$self{config}{no_vcs} = 1;
+			$$self{config}{profile} ||= 'reader';
+		}
+		else { die "File is not part of a notebook: $file\n" }
+	}
+	elsif ($$self{dir} ) {
+		$$self{dir} = dir( $$self{dir} );
+		die "No such directory: $$self{dir}\n"
+			unless $$self{dir}->exists;
+	}
+	# else we may have a type of store without dir or file, e.g. ::Man
 
 	# Read config
-	$$self{config_file} = $class->get_notebook_config($param{dir});
-	$$self{config_file}->read($$self{config}, 'Notebook');
+	$$self{config} ||= {};
+	$$self{config_file} = $self->get_notebook_config;
+	$$self{config_file}->read($$self{config}, 'Notebook')
+		if $$self{config_file};
+
+	# Initialize version control
+	$$self{vcs} ||= $class->check_version_control($$self{dir})
+		if $$self{dir} and not $$self{config}{no_vcs};
+		# we use predefined object in test, hence the "||="
+	if ($$self{vcs}) {
+		my $vcs = ref($$self{vcs});
+		$vcs =~ s/.*:://;
+		warn "# Version Control System: $vcs\n";
+		$$self{dir} = $$self{vcs}->subdir($$self{dir});
+		warn "## Dir type: ".ref($$self{dir})."\n";
+	}
+	else { warn "# Store does not use version control\n" }
+
+	# Setup remaining properties
 	$self->signal_connect(config_changed => \&_init_properties, $self);
 	$self->_init_properties;
 
-	# Set default store if not yet defined
+	# Set default store if not defined in config
 	my $type = $self->{config}{type} || 'Files';
-	$self->add_child(':', $type, %param)
-		unless defined $self->{config}{':'};
+	$self->add_child(':', $type)
+		unless exists  $$self{':'} or
+		       defined $$self{config}{Namespaces}{':'};
 
 	# Initialize stores defined in config
+	# sort should make sure we start with ":"
 	for my $ns (sort keys %{$self->{config}{Namespaces}}) {
 		# remove namespace defnitions from config
 		# allows lines like ":namespace=Class,key=val,key=val"
@@ -146,51 +199,29 @@ sub new {
 }
 
 sub _init_properties {
-	my $self = pop; # pop because we are called from signal
-	my ($dir, $config) = @$self{'dir', 'config'};
+	my $self = pop; # pop because are also called from signal
+	my $config = $$self{config};
+	#use Data::Dumper; warn Dumper $config;
 
-	$$dir{slow_fs} = $$config{slow_fs};
+	# we always want a name
+	$$self{name} = $$config{name};
+	$$self{name} ||= $$self{dir} ? $$self{dir}->path : $$config{type} ;
 
-	if ($$config{DirType}) {
-		my $class = 'Zim::FS::'.$$config{DirType};
-		eval "use $class"; die $@ if $@;
-		$$self{dir} = $class->new($dir);
-		$dir = $$self{dir};
-	}
-	warn "## root uses dir: $$self{dir} (".ref($$self{dir}).")\n";
+	# slow fs
+	$$self{dir}{slow_fs} = $$config{slow_fs} if $$self{dir};
 
+	# doc root
 	my $doc_root = $$config{document_root};
-	$doc_root = dir( Zim::FS->abs_path($doc_root, $dir) )
-		if defined $doc_root and ! ref $doc_root;
-	# TODO make sure that if dir falls below document_dir, or document_dir
-	#      below dir they are properly nested. Also respect if
-	#      either one is under a VCS 
-	#      ... need auto-detect VCS instead of "DirType" ?
+	if (defined $doc_root and $doc_root =~ /\S/) {
+		# proper nesting of doc_root for version control etc.
+		$doc_root = dir( Zim::FS->abs_path($doc_root, $$self{dir}) );
+		my ($parent) = grep { Zim::FS->rel_path($doc_root, $_) }
+		               grep defined($_), $$self{dir}, $$self{vcs} ;
+		$doc_root = $parent->subdir($doc_root) if defined $parent;
+	}
 	$$self{document_root} = $doc_root;
 }
 
-=item C<init_history()>
-
-Initializes a L<Zim::History> to be used with this repository.
-Returns the history object or undef.
-
-=cut
-
-sub init_history {
-	my $self = shift;
-	my $dir = Zim->get_notebook_cache($$self{dir});
-	my $file = $dir->file('history.cache');
-	
-	warn "# History file: $file\n";
-	my $max = $self->{config}{hist_max} || 15;
-	eval {
-		$self->{history} ||= Zim::History->new($file, $max, undef);
-	};
-	warn $@ if $@;
-	
-	return $self->{history};
-}
-
 =item C<add_child(NAMESPACE, CHILD, ...)>
 
 This will connect a new child object to this repository under a certain
@@ -202,9 +233,10 @@ All remaining arguments will be passed on to the constructor of the object.
 
 sub add_child {
 	my ($self, $namespace, $child, %args) = @_;
-	$namespace =~ s/:?$/:/;
-	_check_namespace($namespace);
+	$namespace = Zim::Store->clean_name($namespace); # allow human input
+	$namespace .= ':';
 	warn "# Adding store of type '$child' at '$namespace'\n";
+	_check_namespace($namespace);
 	$args{namespace} = $namespace;
 
 	my $class = "Zim::Store::" .
@@ -229,6 +261,60 @@ sub add_child {
 	#warn "regex: $self->{regex}\n";
 }
 
+=item C<init_history()>
+
+Open or initialize the history for this notebook. Returns an object of
+class L<Zim::History>.
+
+=cut
+
+sub init_history {
+	my $self = shift;
+	return $$self{history} if $$self{history};
+	
+	my $cache = $self->get_notebook_cache;
+	my $hist_file = $cache->file('history.cache');
+	my $hist_max = $$self{config}{hist_max} || 15;
+	warn "# History file: $hist_file (max $hist_max)\n";
+
+	$$self{history} = Zim::History->new($hist_file, $hist_max, undef);
+	return $$self{history};
+}
+
+=item C<init_vcs(VCS)>
+
+Initializes a Version Control System for the top level notebook dir.
+VCS is the system you want to use, e.g. 'Bazaar'. Only needs to be called
+for notebooks that are not yet under version control.
+
+=cut
+
+sub init_vcs {
+	my ($self, $vcs) = @_;
+	die "BUG: can not initialize VCS without directoy" unless $$self{dir};
+	
+	# Expect this eval to die e.g. when the correct VCS is
+	# not installed and can not be used; or e.g. when installed
+	# version has version mis-match etc.
+	my $class = "Zim::FS::$vcs";
+	eval "require $class";
+	die $@ if $@;
+
+	my $dir = $$self{dir};
+	$vcs = $$self{dir} = $$self{vcs} = $class->init($$self{dir});
+	$self->_init_properties; # will properly nest doc_root
+
+	for my $child (map $$self{$_}, grep /^:/, keys %$self) {
+		# make sure all childs use vcs as parent, hope childs
+		# do not store derived sub objects elsewhere
+		# $dir is the old object, $vcs is the new dir object
+		$$child{dir} = $vcs->subdir( $$child{dir}->rel_path )
+			if $$child{dir} and $$child{dir}->parent eq $dir;
+		$$child{file} = $vcs->subdir( $$child{file}->rel_path )
+			if $$child{file} and $$child{file}->parent eq $dir;
+	}
+}
+
 =item C<save()>
 
 Save config, history, etc. to disk.
@@ -238,7 +324,8 @@ Save config, history, etc. to disk.
 sub save {
 	my $self = shift;
 	return 0 if $$self{config}{read_only};
-	$$self{config_file}->write($$self{config}, 'Notebook');
+	$$self{config_file}->write($$self{config}, 'Notebook')
+		if $$self{config_file};
 	$self->{history}->write if $self->{history};
 	return 1;
 }
@@ -251,17 +338,6 @@ Returns self.
 
 sub root { return $_[0] }
 
-=item C<base()>
-
-Returns the base directory for files.
-
-The "base" directories for individual pages should either be the same as
-this directory or a subdirectory of it.
-
-=cut
-
-sub base { return $_[0]->{dir} }
-
 ## 3 methods for checking arguments ##
 
 sub _check_page {
@@ -341,10 +417,9 @@ sub get_page {
 	return $self->{lc($1)}->get_page($name);
 }
 
-=item C<resolve_page(LINK, PAGE, NO_DEFAULT)>
+=item C<resolve_page(LINK, PAGE, REFERENCE, NO_DEFAULT)>
 
-Like C<get_page()> but now expecting NAME to be user input,
-so NAME is sanitized first.
+Convenience function combining C<resolve_name()> and C<get_page()>.
 
 =cut
 
@@ -557,14 +632,6 @@ sub interwiki_lookup {
 	return $url;
 }
 
-=item C<get_history()>
-
-Return a object of class L<Zim::History> or undef.
-
-=cut
-
-sub get_history { $_[0]{history} }
-
 ####
 
 sub _flush_cache { # TODO TODO good API for this
@@ -588,7 +655,8 @@ See detailed docs in L<Zim::Store>.
 
 =item C<document_dir(PAGE)>
 
-Returns the document dir for PAGE.
+Returns the document dir for PAGE or undef.
+Returns top level dir if PAGE is undefined.
 
 =cut
 
@@ -660,7 +728,9 @@ These methods can be called as C<< Zim->method(...) >>.
 
 =item C<get_notebook_config(DIR)>
 
-Return a config file for the notebook at DIR.
+Return a config file for the notebook at DIR or undef.
+
+Also can be called as object method on the main notebook object.
 
 =item C<get_notebook_cache(DIR)>
 
@@ -668,10 +738,15 @@ Returns a dir to store e.g. history and other state files.
 By default this is either ".zim/" in the notebook directory
 or a directory under XDG_CACHE.
 
+Also can be called as object method on the main notebook object.
+
 =cut
 
 sub get_notebook_config {
 	my ($class, $dir) = @_;
+	$dir = $$class{dir} if ref $class and ! defined $dir;
+	return undef unless defined $dir;
+
 	my ($file) = grep {-e $_}
 	             map  "$dir/$_", qw/notebook.zim .notebook.zim/;
 	$file = "$dir/notebook.zim" unless defined $file;
@@ -680,21 +755,29 @@ sub get_notebook_config {
 
 sub get_notebook_cache {
 	my ($class, $dir) = @_;
-
-	# If dir is an object already it can have a property "slow_fs"
-	# FIXME should we check notebook.zim for this property if we
-	# get a path ?
-	unless (ref($dir) and $$dir{slow_fs}) {
-		my $cache = dir( $dir."/.zim" );
-		# do not use subdir here - cache should e.g. not be under VCS
-		return $cache if $cache->writable;
+	unless (defined $dir) {
+		return undef unless ref $class; # no OO call
+		$dir = $$class{dir};
 	}
+
+	$dir = dir($dir) if defined $dir;
+		# FIXME if dir is an object already it can have a property 
+		# "slow_fs" should we check notebook.zim for this property 
+		# if we get a path ?
 	
-	# logic similar to login in cache_file() in FS.pm
-	my $name = Zim::FS->abs_path($dir);
-	$name =~ s/[\/\\:]+/_/g; # win32 save
-	$name =~ s/^_+|_+$//g;
-	return dir(xdg_cache_home(), 'zim', $name);
+	if (!defined $dir or $$dir{slow_fs} or ! $dir->writable) {
+		# use cache dir instead of notebook dir
+		# logic similar to login in cache_file() in FS.pm
+		my $key = $dir ? $dir->path : $$class{name} ;
+		return undef unless $key =~ /\w/;
+		$key =~ s/[\/\\:]+/_/g; # win32 save
+		$key =~ s/^_+|_+$//g;
+		return dir(xdg_cache_home(), 'zim', $key);
+	}
+
+	my $cache = dir( "$dir/.zim" );
+		# do not use subdir here - cache should e.g. not be under VCS
+	return $cache if $cache->writable;
 }
 
 =item C<is_notebook(DIR)>
@@ -747,7 +830,7 @@ sub get_notebook {
 		if $name eq '_default_' and $n !~ /[\\\/]/;
 		# recurs when default is not a path but a name
 
-	return dir($n) ;
+	return -f $n ? file($n) : dir($n) ;
 }
 
 sub get_notebook_list {
@@ -777,6 +860,45 @@ sub set_notebook_list {
 	file($file)->write(@lines);
 }
 
+=item C<check_version_control(DIR)>
+
+Checks if DIR is under one of the supported version control systems and
+returns an object for the root dir of the version control repository or undef.
+
+=cut 
+
+sub check_version_control {
+	my (undef, $dir) = @_;
+	my $vcs;
+
+	# We scan for VCS by going trough the path looking for meta directories.
+	# An alternative would be to call the actual binaries and let them
+	# figure it out (most VCS will do such a path scan themselves).
+	# However that would require one or more external processes with a
+	# potential performance hit at startup.
+	my $path;
+	my @path = split '/', $dir;
+	while (@path) {
+		$path = join '/', @path;
+		if    (-d "$path/.bzr") { $vcs = 'Bazaar' }
+		elsif (-d "$path/.svn") { $vcs = 'Subversion' }
+		# Here should go tests for other systems
+		last if $vcs;
+		pop @path;
+	}
+	eval {
+		# Expect this eval to die e.g. when the correct VCS is
+		# not installed and can not be used; or e.g. when installed
+		# version has version mis-match etc.
+		my $class = "Zim::FS::$vcs";
+		eval "require $class";
+		die $@ if $@;
+		$vcs = $class->new($path);
+	} if $vcs;
+	warn $@ if $@;
+	return ref($vcs) ? $vcs : undef;
+}
+
 1;
 
 __END__
