@@ -4,7 +4,7 @@ use strict;
 no warnings;
 use Zim::Formats;
 
-our $VERSION = '0.20';
+our $VERSION = '0.26';
 our @ISA = qw/Zim::Formats/;
 
 # TODO: some tags can be nested: email links for example
@@ -44,30 +44,78 @@ sub load_tree { # TODO whitelines between verbatim blocks should be preserved
 	my ($class, $io, $page) = @_;
 
 	my @tree;
-	my $para = '';
+	my $para = ''; # paragraph buffer
+	my $first = 1; # used to detect the first paragraph
+	my $verbatim = 0; # true when inside a verbatim block
 	while (<$io>) {
 		s/\r?\n$/\n/; # DOS to Unix conversion
-		if (!/\S/) {
-			push @tree, $class->parse_para($para) if $para =~ /\S/;
+		unless (/\S/) { # empty line
+			if ($verbatim and $para !~ /^\s*'''\s*\Z/m) {
+				$para .= $_;
+				next;
+			}
+			else { $verbatim = 0 }
+
+			if ($first and $para =~ 
+				/^Content-Type:\s+text\/x-zim-wiki/i
+			) {
+				# First paragraph looking like meta header
+				$class->parse_page_properties($page, $para);
+			}
+			elsif (length $para) {
+				# All other para, verbatim and headers
+				push @tree, $class->parse_para($para, $page);
+			}
 			$tree[-1][1]{empty_lines}++ if scalar @tree;
+				# count empty lines
 			$para = '';
+			$first = 0;
 		}
-		elsif (/^==+\s+\S+/) {
-			push @tree, $class->parse_para($para) if $para =~ /\S/;
-			push @tree, $class->parse_head($_);
-			$para = '';
+		else { # non-empty line
+			$verbatim = 1 if /^\s*'''\s*$/ and $para eq '';
+				# toggle verbatim at start of para
+			$para .= $_;
 		}
-		#elsif (/^\$\$+\s+.*?\s+\$\$\s*$/) {
-		#	push @tree, $class->parse_para($para) if $para =~ /\S/;
-		#	push @tree, $class->parse_object($_);
-		#	$para = '';
-		#}
-		else { $para .= $_ }
 	}
-	push @tree, $class->parse_para($para) if $para =~ /\S/;
+	push @tree, $class->parse_para($para, $page) if length $para;
 	
 	#use Data::Dumper; print STDERR Dumper \@tree;
-	return ['Page', {}, @tree];
+	return ['Page', $$page{properties}, @tree];
+}
+
+sub parse_para {
+	my ($class, $text, $page) = @_;
+
+	# check Verbatim paragraphs
+	my $version = $$page{properties}{'Wiki-Format'};
+	$version =~ s/zim\s+//;
+	if ( (!$version or $version < 0.26) and $text !~ /^(?!\t|\s\s+)/m) {
+		# verbatim blocks before 0.26 need to start
+		# with all whitespace, either tab or multiple spaces
+		my ($indent) = ($text =~ /^(\s+)/);
+		$text =~ s/^$indent//mg;
+		return ['Verbatim', {}, $text];
+	}
+	if ($text =~ m/\A\s*'''\s*$/m and $text =~ m/^\s*'''\s*\Z/m) {
+		# parsing Verbatim paragraphs for version >= 0.26
+		# just remove surrounding "'''" quotes
+		$text =~ s/\A\s*'''\s*$|^\s*'''\s*\Z//mg;
+		$text =~ s/^\n//;
+		return ['Verbatim', {}, $text];
+	}
+
+	# Separate headers and paragraphs
+	return grep defined($_), map {
+		if (!/\S/) { undef }
+		elsif (/^==+\s+\S+/) { # header
+			$class->parse_head($_);
+		}
+		else { # paragraph
+			s/^\n//;
+			s/^(\s*)\*(\s+)/$1\x{2022}$2/mg; # bullet lists
+			['Para', {}, $class->parse_block($_, $page)];
+		}
+	} split /^(==+\s+\S+.*)$/m, $text;
 }
 
 sub parse_head { # parse a header
@@ -79,34 +127,19 @@ sub parse_head { # parse a header
 	return ['head'.$level, {}, $head];
 }
 
-sub parse_object { # FIXME use image syntax for all objects
-	my ($class, $obj) = @_;
-	chomp $obj;
-	$obj =~ s/^\$\$\s+(.*?)\s+\$\$\s*$/$1/;
-	return ['object', {type => 'text'}, $obj];
-}
-
-sub parse_para { # distinguise normal paras from verbatim paras
-	my ($class, $text) = @_;
-	return  $class->parse_Verbatim($text) unless $text =~ /^(?!\t|\s\s+)/m;
-	#$text =~ s/^\.//mg unless $text =~ /^(?!\.?\t|\.?\s\s+)/s;
-	$text =~ s/^(\s*)\*(\s+)/$1\x{2022}$2/mg;
-	return ['Para', {}, $class->parse_block($text)];
-}
-
-sub parse_Verbatim { # parse pre formated paragraphs
-	my ($class, $pre) = @_;
-	my ($indent) = ($pre =~ /^(\s+)/);
-	$pre =~ s/^$indent//mg;
-	return ['Verbatim', {}, $pre];
-}
-
-our @parser_subs = qw/parse_verbatim parse_links parse_images parse_styles parse_urls/;
+our @parser_subs = qw/
+	parse_verbatim
+	parse_links
+	parse_images
+	parse_styles
+	parse_urls
+/;
 
 sub parse_block { # parse a block of text
-	my ($class, @text) = @_;
+	my ($class, $text, $page) = @_;
+	my @text = ($text);
 	for my $sub (@parser_subs) {
-		@text = map {ref($_) ? $_ : ($class->$sub($_))} @text;
+		@text = map {ref($_) ? $_ : ($class->$sub($_, $page))} @text;
 	}
 	return @text;
 }
@@ -157,7 +190,7 @@ sub parse_urls {
 		)#x, $text;
 		# The host name in an uri can be "[hex:hex:..]" for ipv6
 		# but we do not want to match "[http://foo.org]"
-		# See rfc3986 for the official -but unpractical- regex
+		# See rfc/3986 for the official -but unpractical- regex
 }
 
 sub parse_styles { # parse blocks of bold, italic and underline
@@ -178,7 +211,7 @@ sub parse_styles { # parse blocks of bold, italic and underline
 }
 
 sub parse_images {
-	my ($class, $text) = @_;
+	my ($class, $text, $page) = @_;
 	my $i = 0;
 	my @parts =
 		map   { ($i++ % 2) ? ['image', {src => $_}] : $_ }
@@ -189,6 +222,8 @@ sub parse_images {
 			my %arg = split /[=&]/, $1;
 			$$p[1]{$_} = $arg{$_} for keys %arg;
 		}
+		$$p[1]{file} = $page->resolve_file($$p[1]{src});
+		#use Data::Dumper; warn "IMAGE: ", Dumper $p;
 	}
 	return @parts;
 }
@@ -202,7 +237,12 @@ to a filehandle.
 
 sub save_tree {
 	# TODO add support for recursive tags
-	my ($class, $io, $tree) = @_;
+	my ($class, $io, $tree, $page) = @_;
+
+	my $p = $$page{properties};
+	$$p{'Content-Type'} = 'text/x-zim-wiki';
+	$$p{'Wiki-Format'} = 'zim 0.26';
+	print $io $class->dump_page_properties($page), "\n";
 
 	my $old_fh = select $io;
 	eval { $class->_save_tree($tree) };
@@ -226,30 +266,42 @@ sub _save_tree {
 		}
 	
 		my ($tag, $meta) = @$node[0, 1];
+		
+		# Blocks
 		if ($tag eq 'Para') {
-			$class->_save_tree($node);
-			print "\n"x$$meta{empty_lines} if $$meta{empty_lines};
+			$class->_save_tree($node); # recurs
+			# except for the last, a para always needs a newline
+			$$meta{empty_lines} ||= (@$tree ? 1 : 0);
+			print "\n"x$$meta{empty_lines};
 			next;
 		}
-		
-		my $text = _dump($node);		
-		if ($tag eq 'Verbatim')  {
-			$text =~ s/^/\t/mg;
+		elsif ($tag eq 'Verbatim') {
+			my $text = _dump($node);
+			# make sure there are no empty lines between the
+			# paragraph and the block quotes
+			$text =~ s/(\n?)$/\n/;
+			$$meta{empty_lines}-- if defined $1;
+			$text =~ s/^(\n*)/$1'''\n/;
+			$text =~ s/(\n*)$/\n'''$1/;
 			print $text;
+			# except for the last, a para always needs a newline
+			$$meta{empty_lines} ||= (@$tree ? 1 : 0);
+			print "\n"x$$meta{empty_lines};
+			next;
 		}
-		elsif ($tag =~ /^head(\d)$/) {
+
+		# inline tags
+		my $text = _dump($node);
+		if ($tag =~ /^head(\d)$/) {
 			my $n = 7 - $1;
 			print ( ('='x$n)." $text ".('='x$n)."\n" );
 		}
 		elsif ($tag eq 'image') {
 			my $file = $$meta{src};
-			my @k = grep $$meta{$_}, qw/height width/;
+			my @k = sort grep {$_ !~ /^(src|file)$/} keys %$meta;
 			$file .= '?' . join '&', map "$_=$$meta{$_}", @k if @k;
 			print '{{'.$file.'}}';
 		}
-#		elsif ($tag eq 'object') { # FIXME use image syntax for all objects
-#			print "\$\$ $text \$\$\n";
-#		}
 		elsif ($tag eq 'link') {
 			my $to = $$meta{to};
 			$to =~ s/^mailto:// unless $text =~ /^mailto:/;
