@@ -20,7 +20,7 @@ my $has_mimeapplications = $@ ? 0 : 1;
 warn "WARNING: Could not use 'File::MimeInfo::Applications', disabling application bindings\n"
 	unless $has_mimeapplications;
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
@@ -149,6 +149,7 @@ browser
 file_browser
 email_client
 text_editor
+diff_editor
 undo_max	50
 follow_new_link	0
 backsp_unindent	1
@@ -157,6 +158,7 @@ use_camelcase	1
 use_utf8_ent	1
 use_linkfiles	1
 use_autolink	0
+use_autoincr	1
 textfont
 tearoff_menus	0
 use_autoselect	1
@@ -165,6 +167,7 @@ use_ctrl_space	1
 ro_cursor	0
 expand_tree	0
 save_interval	5000
+autosave_version 0
 };
 
 our %DEFAULTS;
@@ -196,11 +199,14 @@ NewPage		gtk-new		_New Page	<ctrl>N		New page
 popup_NewPage	gtk-new		_New Page	.		New page
 OpenNotebook	gtk-open	_Open Another Notebook...	<ctrl>O	Open notebook
 Save		gtk-save	_Save		<ctrl>S		Save page
-SaveCopy	gtk-save-as	S_ave A Copy...	<shift><ctrl>S	Save a copy
+SaveVersion	gtk-save-as	S_ave Version...	<ctrl><shift>S	Save Version
+Versions	.		_Versions...	.		Versions
 Export		.		E_xport...	.		Export
 EmailPage	.		_Send To...	.		Mail page
+CopyPage	.		_Copy Page...	.		Copy page
+popup_CopyPage	.		_Copy Page...	.		Copy page
 RenamePage	.		_Rename Page...	F2		Rename page
-popup_RenamePage	.		_Rename Page...	.		Rename page
+popup_RenamePage	.	_Rename Page...	.		Rename page
 DeletePage	.		_Delete Page	.		Delete page
 popup_DeletePage	.	_Delete Page	.		Delete page
 Props		gtk-properties	Proper_ties	.		Properties dialog
@@ -230,7 +236,6 @@ ShowHelpKeys	.		_Keybindings	.		Key bindings
 ShowHelpBugs	.		_Bugs		.		Bugs
 About		gtk-about	_About		.		About
 } );
-#Versions	.		_Versions...	.		Versions
 
 my $ui_toggle_actions = __actions(
 # name,		stock id,	label,		accelerator,	tooltip 
@@ -256,9 +261,10 @@ my $ui_layout = q{<ui>
 			<menuitem action='OpenNotebook'/>
 			<separator/>
 			<menuitem action='Save'/>
-			<menuitem action='SaveCopy'/>
-			<menuitem action='Export'/>
+			<menuitem action='SaveVersion'/>
+			<menuitem action='Versions'/>
 			<separator/>
+			<menuitem action='Export'/>
 			<placeholder name='PrintActions'/>
 			<menuitem action='EmailPage'/>
 			<separator/>
@@ -359,17 +365,18 @@ my $ui_layout = q{<ui>
 	</toolbar>
 	<popup name='PagePopup'>
 		<menuitem action='popup_NewPage'/>
+		<menuitem action='popup_CopyPage'/>
 		<menuitem action='popup_RenamePage'/>
 		<menuitem action='popup_DeletePage'/>
 	</popup>
 	<accelerator action='GoChild'/>
 </ui>};
-#			<menuitem action='Versions'/>
 
 my $ui_layout_rw = q{<ui>
 <menubar name='MenuBar'>
 		<menu action='FileMenu'>
 			<placeholder name='PageMods'>
+				<menuitem action='CopyPage'/>
 				<menuitem action='RenamePage'/>
 				<menuitem action='DeletePage'/>
 			</placeholder>
@@ -393,15 +400,9 @@ sub init {
 	$self->{_message_timeout} = -1;
 	$self->{_save_timeout}    = -1;
 	
-	# load notebook
-	my $notebook = $self->{notebook}
-		|| Zim->new(
-			dir    => $$self{dir},
-			type   => $$self{type},
-		);
-	$self->{history} = $notebook->init_history();
-	$self->{notebook} = $notebook;
-
+	# check notebook
+	my $notebook = $self->{notebook} or die "BUG: no notebook defined";
+	$self->{history} = $notebook->init_history;
 	$self->{profile} ||= $$notebook{config}{profile} || 'default';
 	
 	# load state parameters
@@ -411,10 +412,12 @@ sub init {
 		my ($key, $val) = split /\s+/, $_, 2;
 		$state{$key} = $val
 	}
-	my $cache_dir = Zim->get_notebook_cache($$notebook{dir});
-	$$self{state_file} =
-		Zim::FS::File::Config->new($cache_dir, 'state.conf');
-	$$self{state} = $$self{state_file}->read(\%state, 'GUI State');
+	my $cache_dir = $notebook->get_notebook_cache;
+	if (defined $cache_dir) {
+		$$self{state_file} =
+			Zim::FS::File::Config->new($cache_dir, 'state.conf');
+		$$self{state} = $$self{state_file}->read(\%state, 'GUI State');
+	}
 
 	# Load config
 	warn "# Profile: $$self{profile}\n";
@@ -467,11 +470,9 @@ sub _init_properties {
 	my $nb = $$self{notebook};
 	
 	# name
-	$$self{name} = $$nb{config}{name};
-	$$self{name} ||= $$nb{dir}->name; # we always want a name
-	$self->call_daemon('register', $$self{name});
-	warn "# Notebook: $self->{name}\n";
-
+	$self->call_daemon('register', $$nb{name});
+	warn "# Notebook: $$nb{name}\n";
+	
 	# icon
 	if (my $icon = $$nb{config}{icon}) {
 		my $file = Zim::FS->abs_path($icon, $$nb{dir});
@@ -499,6 +500,14 @@ sub _init_properties {
 	$self->actions_set_sensitive(
 		OpenRootFolder => $$nb{config}{document_root} ? 1 : 0,
 	) if $$self{actions};
+
+	# Check version control
+	if ($$nb{config}{autosave_version} and ! $$nb{vcs}) {
+		eval { $self->SaveVersion };
+			# prompt for init version control
+			# eval in case we are not intialized yet etc.
+		$$nb{config}{autosave_version} = 0 if ! $$nb{vcs};
+	}
 }
 
 sub _config_data_files {
@@ -569,12 +578,12 @@ sub gui_init {
 	
 	$self->actions_set_sensitive(
 		Save      => $$self{read_only} ? 0 : 1,
-		SaveCopy  => $$self{read_only} ? 0 : 1,
 		NewPage   => $$self{read_only} ? 0 : 1,
 		GoBack    => 0,
 		GoForward => 0,
 		GoParent  => 0,
-		OpenRootFolder => $$self{notebook}{document_root} ? 1 : 0,
+		OpenRootFolder  => $$self{notebook}{document_root} ? 1 : 0,
+		Versions        => $$self{notebook}{vcs} ? 1 : 0,
 	);
 	
 	$self->add_ui($ui_layout);
@@ -780,6 +789,8 @@ sub gui_show {
 	
 	## Toggle some widgets
 	$self->{message_lock} = 1;
+	$self->TReadOnly($$self{page}{properties}{read_only}||0, 'FORCE');
+		# force emission after first page load
 	my $set = $self->{settings};
 	my $pbtype = lc $$set{pathbar_type};
 	$pbtype = 'recent' unless grep {$_ eq $pbtype}
@@ -812,6 +823,10 @@ Used to present the window and possibly to change window state.
 
 Iconify or hide the window.
 
+=item C<ToggleWindow()>
+
+Calls either C<ShowWindow()> or C<HideWindow>.
+
 =cut
 
 sub ShowWindow {
@@ -851,11 +866,18 @@ sub HideWindow {
 		? $self->hide : $self->iconify ;
 }
 
+sub ToggleWindow {
+	$_[0]->is_active ? $_[0]->HideWindow : $_[0]->ShowWindow;
+		# is_active checks whether we have input focus
+		# == whether we are in the foreground
+}
+
 sub DESTROY {
 	my $self = shift;
 	for (qw/_save_timeout _message_timeout/) {
 		my $timeout = $self->{$_};
-		Glib::Source->remove($timeout) if $timeout >= 0;
+		Glib::Source->remove($timeout)
+			if defined $timeout and $timeout >= 0;
 	}
 }
 
@@ -873,10 +895,12 @@ sub AUTOLOAD {
 	}
 	elsif ($AUTOLOAD =~ /^on_(\w+)$/) { # could be an action handler
 		no strict 'refs';
+		unshift @_, $self;
 		goto &{"Zim::GUI::Component::$AUTOLOAD"}; # call parent
 	}
 	elsif ($AUTOLOAD =~ /^[A-Z]/) {
-		my $class = "Zim::GUI::$AUTOLOAD";
+		my $class = $$self{autoload}{$AUTOLOAD}; 
+		$class ||= "Zim::GUI::$AUTOLOAD";
 		warn "## AUTOLOAD $class\n";
 		eval "require $class";
 		$self->exit_error($@) if $@;
@@ -891,30 +915,6 @@ sub AUTOLOAD {
 	return $self->{window}->$AUTOLOAD(@_);
 }
 
-sub on_delete_event {
-	# Called when the window is deleted
-	# return true to avoid destruction
-	my $self = shift;
-	my $force = uc(shift) eq 'FORCE';
-
-	eval {
-		my ($state, $window) = @{$self}{'state', 'window'};
-		@{$state}{'width', 'height'} = $window->get_size;
-		@{$state}{'x', 'y'} = $window->get_position if $window->visible;
-			# position is 0,0 when window is hidden
-	};
-	
-	if ($self->{hide_on_delete} and !$force) {
-		$self->{window}->hide;
-		return 1;
-	}
-	
-	$self->SaveIfModified() || return 1;
-	$self->SaveState;
-
-	return 0;
-}
-
 =item C<current()>
 
 Returns a reference to the current Zim::GUI object. Class method used in plugin
@@ -947,13 +947,14 @@ sub plug { # TODO add plugin to config
 			__("No such plugin: {name}", name => $name) );
 	}
 
-	warn "# Loading plugin $name from $script\n";
+	warn "# Loading plugin $name\n";
+	warn "## from $script\n";
 	local $CURRENT = $self;
 	my $return = do $script;
 	if ($@ or ! defined $return) {
 		$self->unplug($name);
 		return $self->error_dialog(
-			__("Failed to load plugin: {name}", name => $name),
+			__("Failed to load plugin: {name}", name => $name), #. error
 			$@ || $! );
 	}
 
@@ -1031,7 +1032,8 @@ sub SaveSettings {
 sub SaveState {
 	my $self = shift;
 	$$self{state}{pane_pos} = $$self{hpaned}->get_position;
-	$$self{state_file}->write($$self{state}, 'GUI State');
+	$$self{state_file}->write($$self{state}, 'GUI State')
+		if $$self{state_file};
 }
 
 =item C<LoadSettings()>
@@ -1084,11 +1086,11 @@ LINK is a file or an url.
 sub link_clicked {
 	my ($self, $link) = @_;
 	$link =~ s/^\s+|\s+$//g; # no whitespace pre- or post-fix
-	#warn "link clicked: >>$link<<\n";
 	return warn "WARNING: You tried to folow an empty link.\n"
 		unless length $link;
 
 	my ($type, $l) = $self->{page}->parse_link($link);
+	warn "## Link clicked: $link ($type: $l)\n";
 	return $self->error_dialog("Link undefined: $link")
 	       unless defined $type;
 	
@@ -1100,7 +1102,7 @@ sub link_clicked {
 		my $page = $1;
 		$self->OpenNotebook($l, $page) if length $l;
 	}
-	elsif ($type eq 'man')  { $self->ShowHelp(':man:'.$l)  }
+	elsif ($type eq 'man')  { $self->ShowHelp('_man_', $l) }
 	else                    { $self->open_url($l, $type)   }
 }
 
@@ -1113,49 +1115,59 @@ Calls C<open_directory()> when FILE is a directory.
 
 sub open_file {
 	my ($self, $file) = @_;
-	return $self->open_directory($file) if $file =~ /\/$/ or ! -f $file;
-		# ! -f catches both existence and dirs
-	my $mt = mimetype("$file");
+	return $self->open_directory($file) if $file =~ /\/$/ or -d $file;
+		# Just to make sure we are dealing with files here
 	
-	return $self->open_directory($file, 'OPEN_FILE')
-		unless $mt and $has_mimeapplications;
-	
-	my ($app) = grep $_, mime_applications($mt);
-		# if no default, select first
-		# FIXME: ask user for default
+	my $app;
+	if ($has_mimeapplications) {
+		my $mt = mimetype("$file");
+		($app) = grep $_, mime_applications($mt) if defined $mt;
+			# If no default application is set,
+			# we use the first in the list
+	}
 
-	return $self->open_directory($file, 'OPEN_FILE') unless $app;
+	return $self->open_directory($file, 'OPEN_FILE') unless defined $app;
+		# Open directory in case we do not have a mimetype,
+		# or we do not have an application, or we do not have
+		# the libs to determine that.
 
-	unless (fork) { # child process
+	unless (fork) {
+		# child process that executes the application
+		# $app is a File::DesktopEntry object and knows about win32
 		warn '# Executing '.$app->get_value('Name')." on $file\n";
 		eval { $app->exec($file) };
 		exit 1;
 	}
+
 	return 1; # assume fork worked OK
 }
 
 =item C<open_directory(DIR)>
 
-Opens DIR in the file browser. Open the parent directory when
-DIR turns out to be a file.
+Opens DIR in the file browser.
+
+If it is unknown if we are dealing with a file or a dir, use C<open_file()>.
 
 =cut
 
 sub open_directory {
-	my ($self, $dir, $open_file) = @_; # open_file is a private arg
+	my ($self, $dir, $open_file) = @_;
+		# open_file is a private arg used by open_file() to
+		# flag that we try to open a file instead of a dir
 	
 	my $browser = $self->_ask_app('file_browser', __('File browser')) #. application type
 		or return 0;
 	
-	if ( ! -d $dir and (! $open_file or $browser =~ /\%d/) ) {
-		# strip filename if $dir is a file
-		# we default to %f is $open_file
+	$dir = Zim::FS->localize($dir);
+	my $file = $dir;
+	if ($open_file or -f $dir) {
+		# Get rid of the file part of the path
 		my ($vol, $dirs, undef) = File::Spec->splitpath($dir);
 		$dir = File::Spec->catpath($vol, $dirs);
 	}
-	$dir = Zim::FS->localize($dir);
-
+	
 	unless (-d $dir) {
+		# Check existense of the directory part
 		my $answer = $self->prompt_question( 'question',
 			__("<b>Folder does not exist.</b>\n\nThe folder: {path}\ndoes not exist, do you want to create it now?", path => $dir), #. Dialog question, answers are 'yes' or 'no'
 			['no', 'gtk-no'], ['yes', 'gtk-yes'] );
@@ -1163,7 +1175,20 @@ sub open_directory {
 		$dir->touch;
 	}
 
-	$browser =~ s/\%[sfd]/$dir/ or $browser .= " \"$dir\"";
+	if ($open_file) {
+		$browser =~ s/\%([fds])/($1 eq 'f') ? $file : $dir/eg
+			or $browser .= " \"$dir\"";
+		# %f means the filebrowser can open files directly
+		#    this can be used if we don't have mime libraries
+		#    but the filebrowser knows how to do it.
+		# %d means we only try to open directories
+		# %s is same as %d and is included for backwards compatibility
+	}
+	else {
+		$browser =~ s/\%([fds])/$dir/eg
+			or $browser .= " \"$dir\"";
+	}
+	
 	Zim::Utils->run($browser);
 	return 1;
 }
@@ -1297,9 +1322,9 @@ sub _load_page { # load _without_ saving first
 	$self->update_status();
 	my $links = scalar $page->list_backlinks;
 	$self->{statusl}->set_text_with_mnemonic(
-		__("{number} _Back links", number => $links).'...');
+		__n("{number} _Back link", "{number} _Back links", number => $links).'...' );
 
-	$self->{history}->write if $self->{history};
+	$self->{history}->write if $self->{history}; # Save history
 }
 
 =item C<TReadOnly(BOOLEAN)>
@@ -1310,11 +1335,13 @@ This emits the C<t_read_only> signal.
 =cut
 
 sub TReadOnly {
-	my ($self, $read_only) = @_;
+	my ($self, $read_only, $force) = @_; # force is a private arg
 	$read_only = $$self{read_only} ? 0 : 1 unless defined $read_only;
-	#my @c = caller; warn "TR get $read_only ($$self{read_only}, $$self{read_only_lock}) from $c[0] $c[2]\n";
-	return if $$self{read_only_lock};
-	return if $read_only == $$self{read_only};
+	#my @c = caller; warn "TR get $read_only ($$self{read_only}, $$self{read_only_lock}) from @c\n";
+	unless ($force) {
+		return if $$self{read_only_lock};
+		return if $read_only == $$self{read_only};
+	}
 	$$self{read_only} = $read_only;
 	$self->actions_set_sensitive(
 		Save => !$read_only,
@@ -1377,13 +1404,16 @@ When NOTEBOOK is given PAGE can be used to open the notebook at a certain page.
 
 sub OpenNotebook {
 	my ($self, $notebook, $page) = @_;
-	return $self->NotebookDialog->show() unless defined $notebook;
-		# Don't wait for return - NotebookDialog is not modal
-
+	$notebook = '_new_' unless defined $notebook;
 	$page = $page->name if ref $page;
+
+	# first try the daemon
 	$self->call_daemon('open', $notebook, $page) and return;
 	
 	# We are not using daemon or daemon failed
+	return $self->NotebookDialog->show() if $notebook eq '_new_';
+		# Don't wait for return - NotebookDialog is not modal
+
 	$notebook = Zim::FS->localize($notebook)
 		if $notebook =~ m#/#; # path
 	return $self->exec_new_window($notebook, $page);
@@ -1450,7 +1480,7 @@ sub _save_page {
 			$self->_load_page($self->{page}); # load page wihtout saving
 		}
 		elsif ($answer eq 'copy') {
-			return $self->SaveCopy; # recurs indirectly
+			return $self->CopyPage; # recurs indirectly
 		}
 		else { return 0 } # return _without_ removing save_lock
 	}
@@ -1460,56 +1490,134 @@ sub _save_page {
 	return 1;
 }
 
-=item C<SaveCopy()>
+=item C<SaveVersion(COMMENT)>
 
-Prompt the user to save a copy of the current page.
+Prompt for a comment and commit a version. COMMENT is an optional argument
+and will be used as the suggested comment in the dialog.
 
-=cut
-
-sub SaveCopy {
-	my $self = shift;
-	return unless $self->{page};
-
-	# prompt page
-	my $new = $self->{page}->name . '_(Copy)' ;
-	my $val = $self->run_prompt(
-		__('Save Copy'), #. dialog title
-		['page'], {page => [__('Page'), 'page', $new]}, #. enrty label
-		'gtk-save-as', __('_Save Copy'), #. save button
-		'Please enter a name to save' );
-	return unless defined $val;
-	($new) = @$val;
-	return unless length $new;
-
-	my $l = $self->check_page_input($new);
-	my $page = $self->{notebook}->resolve_page($l);
-	return $self->error_dialog(
-		__("Can not save to page: {name}", name => $l) )
-		unless $page;
-	
-	# check if page exists
-	if ($page->exists()) {
-		my $answer = $self->prompt_question( 'warning',
-			__("<b>Page already exists</b>\n\nThe page '{name}'\nalready exists.\nDo you want to overwrite it?", name => $new), #. warning dialog, answers are 'cancel' or 'ovewrite'
-			['cancel', 'gtk-cancel', undef],
-			['overwrite', undef, __('_Overwrite')] ); #. save button
-		return unless $answer eq 'overwrite';
-	}
-	
-	# change page and save buffer
-	$self->{page} = $page;
-	$self->Save;
-	$self->Reload;
-}
+If no version control is enabled prompt for initializing version control.
 
 =item C<Versions()>
 
 Show the versions dialog, see L<Zim::GUI::VersionsDialog>.
 
+=item C<init_vcs_dialog()>
+
+Prompt user to initialize version control, called by C<SaveVersion()>.
+
 =cut
 
+sub SaveVersion {
+	my ($self, $comment) = @_;
+	$self->SaveIfModified or return;
+	
+	return $self->init_vcs_dialog unless $$self{notebook}{vcs};
+
+	# saved log
+	my $cache_dir = $$self{notebook}->get_notebook_cache;
+	my $log = defined($cache_dir)
+		? $cache_dir->file('version-comment.txt')
+		: undef ;
+	if (defined $log and $log->exists) {
+		$comment =~ s/\n?$/\n\n/ if $comment =~ /\S/;
+		$comment .= $log->read;
+	}
+
+	# prompt for comment
+	my $dialog = Gtk2::Dialog->new(
+		__('Save version').' - Zim', $$self{window}, #. dialog title
+		[qw/modal destroy-with-parent no-separator/],
+		'gtk-help' => 'help',
+		'gtk-cancel' => 'cancel',
+		'gtk-save' => 'ok'
+	);
+	#$dialog->vbox->set_spacing(5);
+	$dialog->set_default_size(300, 150);
+	
+	my $vpane = Gtk2::VPaned->new;
+	$dialog->vbox->add($vpane);
+	my $vbox1 = Gtk2::VBox->new;
+	$vpane->add1($vbox1);
+	my $vbox2 = Gtk2::VBox->new;
+	$vpane->add2($vbox2);
+
+	# label and input text field
+	$vbox1->pack_start(
+		Gtk2::Label->new(__('Please enter a comment for this version')), #. dialog text
+		0,1,0 );
+	my ($scroll, $view) = $self->new_textview;
+	$view->get_buffer->set_text( $comment ) if $comment =~ /\S/;
+	$view->set_editable(1);
+	$vbox1->add($scroll);
+
+	# status
+	my $label = Gtk2::Label->new('<b>'.__('Details').'</b>'); #. label
+	$label->set_use_markup(1);
+	$label->set_alignment(0,0.5);
+	$vbox2->pack_start($label, 0,1,0);
+	
+	my ($stscroll, $stview) = $self->new_textview(
+		$$self{notebook}{vcs}->status );
+	$vbox2->add($stscroll);
+	my $hbox = Gtk2::HBox->new;
+	$vbox2->pack_start($hbox, 0,1,0);
+	my $cbutton = Gtk2::Button->new(__('_Notebook Changes...')); #. button
+	$cbutton->signal_connect(clicked =>
+		sub { $self->VersionsDialog->Diff } );
+	$hbox->pack_end($cbutton, 0,1,0);
+
+	# and run
+	$dialog->show_all;
+	while (my $re = $dialog->run) {
+		if ($re eq 'help') {
+			$self->ShowHelp(':Usage:VersionControl');
+			next;
+		}
+
+		my ($start, $end) = $view->get_buffer->get_bounds;
+		$comment = $view->get_buffer->get_text($start, $end, 0);
+		$log->write($comment) if defined $log and $comment =~ /\S/;
+			# write log for next instance of this dialog
+		$dialog->destroy;
+		if ($re eq 'ok') {
+			return $self->error_dialog(
+				__('Can not save a version without comment') ) #. error
+				unless $comment =~ /\S/;
+			eval { $$self{notebook}{vcs}->commit($comment) };
+			return $self->error_dialog(
+				__('Could not save version')."\n\n$@") if $@; #. error
+			$log->remove if defined $log;
+				# if commit succesfull log can be deleted
+		}
+		last;
+	}
+}
+
 sub Versions { pop->VersionsDialog->show() }
 
+sub init_vcs_dialog {
+	my $self = shift;
+	
+	my $text = __("<b>Enable Version Control</b>\n\nVersion control is currently not enabled for this notebook.\nDo you want to enable it ?") #. question dialog, options are 'help', 'cancel' and 'ok'
+	         . "\n\n"
+		 . __("Enabling version control will initialize the <b>Bazaar</b> Version Control System.\nPlease click 'help' to read about the system requirements and alternatives.") ; #. detailed notice in prompt to enable version control
+	my $answer = $self->prompt_question(
+		'question', $text,
+		[help   => 'gtk-help'],
+		[cancel => 'gtk-cancel'],
+		[ok     => 'gtk-ok'] );
+	if ($answer eq 'ok') {
+		eval { $$self{notebook}->init_vcs('Bazaar') };
+		return $self->error_dialog( __('Could not initialize version control')."\n\n$@" ) if $@ or ! $$self{notebook}{vcs}; #. error dialog
+		$self->Reload; # purge page object
+		$self->actions_set_sensitive(Versions => 1);
+		$self->SaveVersion( __("Initial version") ) # indirect recurs #. default comment for first version after initializing version control
+	}
+	elsif ($answer eq 'help') {
+		$self->ShowHelp(':Usage:VersionControl');
+	}
+}
+
 =item C<Export()>
 
 Show the export dialog, see L<Zim::GUI::ExportDialog>.
@@ -1533,6 +1641,53 @@ sub EmailPage {
 	$self->open_url("mailto:?subject=$subject&body=".$src);
 }
 
+=item C<CopyPage()>
+
+Prompt the user to save a copy of the current page.
+
+=cut
+
+sub CopyPage {
+	my ($self, $page) = @_;
+	$page ||= $$self{page};
+	
+	my $copy_current = $$self{page}->equals($page);
+	my $save = $self->SaveIfModified(!$copy_current);
+	return 0 if $copy_current and !$save;
+
+	# prompt page
+	my $new = __('{name}_(Copy)', name => $page); #. default name for new page in save copy action
+	my $val = $self->run_prompt(
+		__('Save Copy'), #. dialog title
+		['page'], {page => [__('Page'), 'page', $new]}, #. enrty label
+		'gtk-save-as', __('_Save Copy'), #. save button
+		__('Please enter a name to save a copy of page: {page}', page => $page) ); #. dialog text
+	return unless defined $val;
+	($new) = @$val;
+	return unless length $new;
+
+	my $l = $self->check_page_input($new);
+	$new = $self->{notebook}->resolve_page($l);
+	return $self->error_dialog(
+		__("Can not save to page: {name}", name => $l) )
+		unless $new;
+	
+	# check if page exists
+	if ($new->exists()) {
+		my $answer = $self->prompt_question( 'warning',
+			__("<b>Page already exists</b>\n\nThe page '{name}'\nalready exists.\nDo you want to overwrite it?", name => $new), #. warning dialog, answers are 'cancel' or 'ovewrite'
+			['cancel', 'gtk-cancel', undef],
+			['overwrite', undef, __('_Overwrite')] ); #. save button
+		return unless $answer eq 'overwrite';
+	}
+	
+	# finally copy page
+	$$self{notebook}->copy_page($page => $new);
+	$self->signal_emit(page_created => $new);
+	
+	return 1;
+}
+
 =item C<RenamePage(FROM, TO, UPDATE_SELF, UPDATE_OTHER)>
 
 Wrapper for C<< Zim->move_page() >>.
@@ -1648,7 +1803,7 @@ sub DeletePage {
 	
 	unless ($noconf) {
 		my $r = $self->prompt_question( 'warning',
-		__("<b>Delete page</b>\n\nAre you sure you want to delete\npage '{name}' ?", name => $name), #. warning dialog, answers are 'yes' or 'no'
+		__("<b>Delete page</b>\n\nAre you sure you want to delete\npage '{name}' ?", name => $name), #. warning dialog, answers are 'cancel' or 'delete'
 			['no',  'gtk-cancel', undef],
 			['yes', 'gtk-delete', undef]  );
 		return unless $r eq 'yes';
@@ -1688,17 +1843,56 @@ Quit the application. Also closes all other instances of zim.
 =cut
 
 sub Close {
-	my $self = shift;
-	$self->on_delete_event(@_) && return;
-	Gtk2->main_quit;
+	$_[0]->on_delete_event($_[1]) || Gtk2->main_quit;
 }
 
 sub Quit {
 	$_[0]->call_daemon('broadcast', 'Close', 'FORCE');
-	$_[0]->call_daemon('main_quit');
 	$_[0]->Close('FORCE');
 }
 
+sub on_delete_event {
+	# Called when the window is deleted or by the Close action
+	# return true to avoid destruction in both cases
+	my $self = shift;
+	my $force = uc(shift) eq 'FORCE';
+
+	# try to get window state, eval because window may be destroyed already
+	eval {
+		my ($state, $window) = @{$self}{'state', 'window'};
+		@{$state}{'width', 'height'} = $window->get_size;
+		@{$state}{'x', 'y'} = $window->get_position if $window->visible;
+			# position is 0,0 when window is hidden
+	};
+	
+	# save state etc. no matter if we really destruct or not
+	$self->SaveIfModified() || return 1;
+	$self->SaveState;
+	$$self{history}->write if $$self{history}; # Save history
+
+	# Hide window already to make it look snappy
+	$$self{window}->hide;
+	while (Gtk2->events_pending) { Gtk2->main_iteration_do(0) }
+	
+	# clean up tmp files - match name Zim::FS->tmp_file
+	my $dir = dir( Zim::FS->tmpdir );
+	my @files = grep /^zim-$ENV{USER}-$$-/, $dir->list;
+	for (@files) {
+		eval { $dir->file($_)->remove };
+		warn $@ if $@;
+	}
+	
+	# check if we really destruct or not
+	return 1 if $$self{hide_on_delete} and !$force;
+
+	# autosave version
+	eval { $$self{notebook}{vcs}->commit("autosave from zim") }
+		if  $$self{notebook}{vcs}
+		and $$self{notebook}{config}{autosave_version} ;
+
+	return 0 
+}
+
 =item C<CopyLocation(PAGE, ...)>
 
 Copies a list of page names to the clipboard.
@@ -2007,7 +2201,6 @@ sub RBIndex {
 	my $tree = $self->TreeView;
 	$tree->{_loaded} = 0;
 	$tree->load_index;
-	$self->Reload;
 }
 
 
@@ -2281,7 +2474,7 @@ sub prompt_rename_page_dialog {
 	my $check1 = Gtk2::CheckButton->new(
 		__("_Update links in this page")); # check box
 	my $check2 = Gtk2::CheckButton->new(
-		__("_Update {number} pages linking here", number => $nlinks)); # check box
+		__n("_Update {number} page linking here", "_Update {number} pages linking here", number => $nlinks)); # check box
 	$check1->set_active(1);
 	if ($nlinks > 0) { $check2->set_active(1)    }
 	else             { $check2->set_sensitive(0) }
