@@ -9,7 +9,7 @@ use File::BaseDir 0.03 qw/data_dirs data_files/;
 use Zim::Events;
 use Zim::Utils;
   
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 our @ISA = qw/Zim::Events/;
 
@@ -93,10 +93,13 @@ in the config file. Intended for use by plugin modules.
 
 When the whole section is missing it will be initialized with %DEFAULTS.
 
+When called on the main application object it will not change 
+C<$$app{settings}> but only return the hash for the section requested.
+
 =item C<init_state(NAME, \%DEFAULTS)>
 
 Like C<init_settings()> but initializes C<$$self{state}> and links to
-file with state variables, not config file.
+the file with state variables, not the config file.
 
 =cut
 
@@ -143,12 +146,15 @@ sub AUTOLOAD {
 	if ($AUTOLOAD =~ s/^on_(\w+)$/$1/) { # could be an action handler
 		my $self = pop;
 		return if $self->{_block_actions};
-		warn "## dispatch ACTION $AUTOLOAD\n";
 		if ($AUTOLOAD =~ s/^popup_//) { # popup menu
 			return $self->$AUTOLOAD(
 				defined($_popup_args) ? (@$_popup_args) : () );
 		}
-		else { return $self->$AUTOLOAD() }
+		else {
+			# GUI action, first try dispath, then default method
+			my $r = $self->signal_dispatch($AUTOLOAD);
+			return $r ? $r : $self->$AUTOLOAD();
+		}
 	}
 	elsif (ref $_[0]) {
 		my $self = shift;
@@ -314,10 +320,10 @@ Any ARGS are forwarded to the actions.
 sub popup {
 	my ($self, $name, $button, $time, @args) = @_;
 	my $menu = $self->{app}{ui}->get_widget('/'.$name) or return 0;
-    unless ($menu) {
-        carp "BUG: no such menu: $name";
-        return 0;
-    }
+	unless ($menu) {
+		carp "BUG: no such menu: $name";
+		return 0;
+	}
 	$_popup_args = scalar(@args) ? \@args : undef;
 	$menu->popup(undef, undef, undef, undef, $button, $time);
 	return 1;
@@ -331,14 +337,23 @@ sub popup {
 
 =item C<ShowHelp(PAGE)>
 
-Show a window showing the documentation. PAGE is optional.
+=item C<ShowHelp(NOTEBOOK, PAGE)>
+
+Show a window showing the documentation. Both PAGE and NOTEBOOK are optional.
+NOTEBOOK defaults to '_doc_' (same as C<--doc> on the commandline) but can
+be specified to be e.g. '_man_' (same as C<--man>).
+
+In the one argument form the page must start with a ':'.
 
 =cut
 
 sub ShowHelp {
-	my ($self, $page) = @_;
-	$self->call_daemon('open', '_doc_', $page) and return;
-	$self->exec_new_window('--doc', $page);
+	my ($self, $notebook, $page) = @_;
+	$notebook = '_doc_' if ! defined $notebook;
+	($notebook, $page) = ('_doc_', $notebook)
+		if ! defined $page and $notebook =~ /^:/;
+	$self->call_daemon('open', $notebook, $page) and return;
+	$self->exec_new_window($notebook, $page);
 }
 
 =back
@@ -463,21 +478,85 @@ sub encode_uri_list {
 
 Creates a button with a stock image but different text.
 
+=item C<new_small_button(STOCK)>
+
+Creates a small button without text.
+
 =cut
 
 sub new_button {
 	my ($self, $stock, $text) = @_;
+	my $button = Gtk2::Button->new();
+	$button->add(Gtk2::Alignment->new(0.5,0.5, 0,0));
 	my $hbox = Gtk2::HBox->new;
 	$hbox->pack_start(
 		Gtk2::Image->new_from_stock($stock, 'button'), 0,0,0);
 	$hbox->pack_start(
 		Gtk2::Label->new_with_mnemonic($text), 1,1,0);
-	my $button = Gtk2::Button->new();
-	$button->add(Gtk2::Alignment->new(0.5,0.5, 0,0));
 	$button->child->add($hbox);
 	return $button;
 }
 
+sub new_small_button {
+	my ($self, $stock) = @_;
+	my $button = Gtk2::Button->new();
+	$button->add(Gtk2::Alignment->new(0.5,0.5, 0,0));
+	$button->child->add(
+		Gtk2::Image->new_from_stock($stock, 'small-toolbar') );
+	return $button;
+}
+
+=item C<new_textview(TEXT)>
+
+Returns a L<Gtk2::ScrolledWindow> and a L<Gtk2::Textview>.
+Sets scrolling, shadow and margins properly.
+
+=cut
+
+sub new_textview {
+	my (undef, $text) = @_;
+	
+	my $textview = Gtk2::TextView->new;
+	$textview->set_editable(0);
+	$textview->set_wrap_mode('word');
+	$textview->set_left_margin(5);
+	$textview->set_right_margin(5);
+	$textview->get_buffer->set_text($text) if defined $text;
+
+	my $scroll = Gtk2::ScrolledWindow->new;
+	$scroll->set_policy('automatic', 'automatic');
+	$scroll->set_shadow_type('in');
+	$scroll->add($textview);
+
+	return ($scroll, $textview);
+}
+
+=item C<set_treeview_single_click(TREEVIEW)>
+
+Make TREEVIEW a single click navigation widget.
+
+=cut
+
+sub set_treeview_single_click {
+	my $tview = pop;
+	$tview->signal_connect(
+		button_release_event => \&on_treeview_single_click);
+}
+
+
+sub on_treeview_single_click {
+	my ($tview, $event) = @_;
+	return 0 if $event->type ne 'button-release';
+	
+	my ($x, $y) = $event->get_coords;
+	my ($path, $column) = $tview->get_path_at_pos($x, $y);
+	return 0 unless $path and $event->button == 1;
+	return 0 unless $tview->get_selection->path_is_selected($path);
+		
+	$tview->row_activated($path, $column);
+	return 0;
+}
+
 =item C<list_text_targets(INFO)>
 
 Returns a list of targets used to copy-paste or drag-drop text.
@@ -614,6 +693,10 @@ sub new_form {
 		elsif ($f[1] eq 'int') {
 			# for integers we use a spin button input
 			my @r = @{$f[3]};
+			$r[0] ||= 0; # min
+			$r[1] = $r[0]+1 unless $r[1] > $r[0];
+				# Some Gtk versions do not allow max == min
+			$r[2] ||= 1; # step
 			$entry = Gtk2::SpinButton->new_with_range(@r);
 			$entry->set_value($f[2]);
 			$table->attach_defaults($entry, 1,2, $i,$i+1);
@@ -717,7 +800,7 @@ sub run_prompt {
 	return $values;
 }
 
-=item C<prompt_question(TITLE, TYPE, TEXT, BUTTONS ..., TIME)>
+=item C<prompt_question(TYPE, TEXT, BUTTONS ..., TIME)>
 
 TYPE can either be 'error', 'warning', 'question', 'info' or C<undef>.
 
@@ -755,6 +838,8 @@ sub prompt_question {
 			: $self->new_button($stock, $string)   ;
 		$button->set_sensitive(0);
 		$dialog->add_action_widget($button, $_);
+		$dialog->action_area->set_child_secondary($button, 1)
+			if $stock eq 'gtk-help';
 		push @button_widgets, $button;
 	}
 	
@@ -800,6 +885,7 @@ sub prompt_question {
 	my $id = $dialog->run;
 	$dialog->destroy;
 	
+	return undef unless $id =~ /^\d+$/;
 	return $buttons[$id][0];
 }
 
@@ -868,7 +954,7 @@ sub filechooser_dialog {
 		? ( $$self{app}{page}->document_dir,
 		    $$self{app}{notebook}->document_dir,
 		    $$self{app}{notebook}->document_root )
-		: (undef, undef) ;
+		: (undef, undef, undef) ;
 		# need to check page here because this method is also
 		# used by e.g. NotebookDialog
 	
@@ -888,12 +974,13 @@ sub filechooser_dialog {
 	# add links to special directories in side pane
 	for (grep {defined $_} $doc_root, $doc_dir_root, $doc_dir) {
 		my $folder = Zim::FS->localize($_);
-		$dialog->add_shortcut_folder($folder) if -e $folder; 
-			# dies for some Gtk version if folder does not exist
+		eval { $dialog->add_shortcut_folder($folder) } if -e $folder; 
+			# dies for some gtk version if folder does not exist
+			# dies for other gtk version if shortcut is double
 	}
 	
 	# set the file or dir we want the dialog to open
-	if (defined $file) {
+	if (defined $file and $file =~ /\S/) {
 		# opens the dir for file (file can be a dir itself)
 		$file = Zim::FS->localize(file($file));
 		$dialog->set_filename($file);
