@@ -19,7 +19,7 @@ use Zim::GUI::Component;
 eval "use Gtk2::Ex::DesktopEntryMenu";
 my $has_mimeapplications = $@ ? 0 : 1;
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 our @ISA = qw/Zim::GUI::Component/;
 
@@ -298,16 +298,13 @@ sub init { # called by new()
 	$vbox->pack_start($hbox, 0, 1, 3);
 	$self->{hbox} = $hbox;
 	
-	my $close_button = Gtk2::Button->new;
+	my $close_button = $self->new_small_button('gtk-close');
 	$close_button->set_relief('none');
-	$close_button->add(Gtk2::Alignment->new(0.5, 0.5, 0, 0));
-	$close_button->child->add(
-		Gtk2::Image->new_from_stock('gtk-close', 'small-toolbar') );
 	$close_button->signal_connect_swapped(
 		clicked => \&CloseFind, $self );
 	$hbox->pack_end($close_button, 0,1,0);
 	
-	$hbox->pack_start( Gtk2::Label->new(' Find: '), 0,1,0);
+	$hbox->pack_start( Gtk2::Label->new(' '.__('Find').': '), 0,1,0); #. query entry label
 	
 	my $entry = Gtk2::Entry->new();
 	$entry->signal_connect(changed => sub { $self->_find($entry->get_text, 0) });
@@ -315,13 +312,13 @@ sub init { # called by new()
 	$hbox->pack_start($entry, 0, 1, 0);
 	$self->{entry} = $entry;
 
-	my $prev_button = $self->new_button('gtk-go-back', '_Previous');
+	my $prev_button = $self->new_button('gtk-go-back', __('_Previous')); #. search button
 	$prev_button->set_sensitive(0);
 	$prev_button->signal_connect_swapped(clicked => \&FindPrev, $self);
 	$hbox->pack_start($prev_button, 0, 1, 0);
 	$self->{find_prev_button} = $prev_button;
 	
-	my $next_button = $self->new_button('gtk-go-forward', '_Next');
+	my $next_button = $self->new_button('gtk-go-forward', __('_Next')); #. search button
 	$next_button->set_sensitive(0);
 	$next_button->signal_connect_swapped(clicked => \&FindNext, $self);
 	$hbox->pack_start($next_button, 0, 1, 0);
@@ -386,7 +383,7 @@ sub _init_buffer {
 	$buffer->signal_connect(edit_mode_changed =>
 		\&on_edit_mode_changed, $self );
 	$self->on_show_cursor;
-	$buffer->{_zim_name} = $self->{app}{name}; # FIXME FIXME FIXME
+	$buffer->{_zim_name} = $self->{app}{notebook}{name}; # FIXME FIXME FIXME
 }
 
 =back
@@ -712,12 +709,12 @@ sub Find {
 	unless ($self->{entry}->visible) {
 		$self->{hbox}->set_no_show_all(0);
 		$self->{hbox}->show_all;
-		$self->{entry}->grab_focus;
 	}
 	if (length $query) {
 		$self->{entry}->set_text($query);
 		$self->_find($query, 0);
 	}
+	$self->{entry}->grab_focus;
 }
 
 sub FindNext { $_[0]->_find( $_[0]->{entry}->get_text, 1  ) }
@@ -806,18 +803,21 @@ sub prompt_date_format {
 
 	my ($file) = data_files('zim', 'dates.list');
 	my @dates;
-	if (defined $file) {
-		for (file($file)->read()) {
-			chomp;
-			! /^\s*#/ and /\S/ or next;
-			push @dates, $_;
-		}
+ 	if (defined $file) {
+ 		for (file($file)->read()) {
+ 			chomp;
+ 			! /^\s*#/ and /\S/ or next;
+ 			push @dates, $_;
+ 		}
+ 	}
+ 	else { @dates = ('%A %d/%m/%Y', '%A %d/%m/%Y %H:%M', '%c', '%x') }
+
+	# For some reason perl 5.10 segfaults if we use a map {} here !?
+	foreach (@dates) {
+	    push @{$view->{data}},
+	    	Encode::decode($CODESET, strftime($_, @$date));
 	}
-	else { @dates = ('%A %d/%m/%Y', '%A %d/%m/%Y %H:%M', '%c', '%x') }
-	@{$view->{data}} =
-		map Encode::decode($CODESET, strftime($_, @$date)),
-		@dates ;
-	
+
 	my $i = $self->{app}{settings}{recent_date_format};
 	$view->select($i) if defined $i;
 	
@@ -1092,7 +1092,7 @@ sub on_drag_data_received {
 	my @items = $self->decode_uri_list($data);
 	my @blocks;
 	if ($type eq 'text/x-zim-page-list') {
-		my $rep = $$self{app}{name};
+		my $rep = $$self{app}{notebook}{name};
 		@blocks = map {
 			if (s/^\Q$rep\E\?//) {
 				$_ = $self->{app}{page}->relative_name($_);
@@ -1673,11 +1673,15 @@ sub parse_line {
 #		$self->{htext}->scroll_mark_onscreen( $buffer->get_insert() );
 #		return 1;
 #	}
-	elsif ($line =~ /^(\s*(:?\W+|\d+\W?|\w\W)\s+|\s+)/) { # auto indenting + lists
+	elsif ($line =~ /^(\s*(:?\W+|\d+\W?|\w\W)\s+|\s+)/) { # auto indenting + aotu incremnt lists
 		my ($indent, $number) = ($1, $2);
+		$number =~ s/\W//g;
 		if (length $number) { # numbered list
-			$number = ($number =~ /\d/) ? $number+1 : chr(ord($number)+1);
-			$indent =~ s/^(\s*)(\d+|\w)/$1$number/;
+			return 0 unless $$self{app}{settings}{use_autoincr};
+			$number = ($number =~ /\d/)
+				? $number+1
+				: chr(ord($number)+1) ;
+			$indent =~ s/(\d+|\w)/$number/;
 		}
 		my $offset = $iter->get_offset;
 		_user_action_ { $buffer->insert($iter, "\n") } $buffer;
@@ -1751,7 +1755,7 @@ sub parse_word {
 	) { # any kind of link
 		my $word = $1;
 		return 0 if $word !~ /[[:alpha:]]{2}/; # at least two letters in there
-		#return 0 unless $word =~ /[^:\dhu]/i; # do not link "10:20h"
+		return 0 if $word =~ /^\d+:/; # do not link "10:20h", "10:20PM" etc.
 		my ($start, $end) = ($iter->copy, $iter->copy);
 		$start->backward_chars(length $word);
 		return 0 if grep {$_->get_property('name') !~ /spell/}
