@@ -4,9 +4,10 @@ use strict;
 use vars '$AUTOLOAD';
 use Gtk2;
 use Gtk2::Gdk::Keysyms;
+use Zim::Utils;
 use Zim::GUI::Component;
 
-our $VERSION = '0.20';
+our $VERSION = '0.26';
 our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
@@ -16,7 +17,7 @@ Zim::GUI::TreeView - Page index widgets
 =head1 DESCRIPTION
 
 This module contains the widgets to display the index 
-of a zim repository as a TreeView.
+of a zim notebook as a TreeView.
 
 =head1 METHODS
 
@@ -34,7 +35,7 @@ Method called by the constructor.
 
 =cut
 
-my ($k_left, $k_right) = @Gtk2::Gdk::Keysyms{qw/Left Right/};
+my ($k_left, $k_right, $k_esc) = @Gtk2::Gdk::Keysyms{qw/Left Right Escape/};
 
 sub init { # called by new()
 	my $self = shift;
@@ -52,7 +53,7 @@ sub init { # called by new()
 	$renderer->signal_connect_swapped(edited => \&on_cell_edited, $self);
 	$self->{renderer} = $renderer;
 	my $page_column = Gtk2::TreeViewColumn->new_with_attributes(
-        	'Pages', $renderer, 'text', 0);
+        	'Pages', $renderer, 'text', 0); # hidden column label
 	$tree_view->append_column($page_column);
 	$tree_view->set_headers_visible(0);
 #	$tree_view->set_reorderable(1);
@@ -69,7 +70,7 @@ sub init { # called by new()
 	$scroll_window->add($tree_view);
 	$self->{tree_view} = $tree_view;
 
-	$self->{app}->signal_connect(page_loaded => sub {$self->select_page(pop)});
+	$self->{app}->signal_connect(page_loaded => sub {$self->select_page(pop, 'TMP')});
 	$self->{app}->signal_connect(page_deleted => sub {$self->unlist_page(pop)});
 	$self->{app}->signal_connect(page_created => sub {
 		my $page = pop;
@@ -85,15 +86,17 @@ sub init { # called by new()
 
 	# drag-n-drop stuff
 	$tree_view->enable_model_drag_source(
-		'button1-mask', ['link', 'move', 'copy'],
+		'button1-mask', ['link'],
 		['text/x-zim-page-list', [], 0] );
 	$tree_view->signal_connect_swapped(
 		drag_data_get => \&on_drag_data_get, $self);
 	$tree_view->enable_model_drag_dest(
-		['link', 'move', 'copy'],
+		['link'],
 		['text/x-zim-page-list', [], 0] );
 	$tree_view->signal_connect_swapped(
 		drag_data_received => \&on_drag_data_received, $self);
+	$tree_view->signal_connect(drag_begin => sub { $$self{drag_lock} = 1 });
+	$tree_view->signal_connect(drag_end => sub { $$self{drag_lock} = 0 });
 
 
 	$self->{widget} = $self->{tree_view};
@@ -104,8 +107,8 @@ sub on_drag_data_get { # we are drag source
         my ($self, $context, $selection_data, $info, $time) = @_;
 	return unless $info == 0; # text/x-zim-page-list
 
-	my $rep = $self->{app}{name};
-	warn "BUG: no repository name set!" unless length($rep);
+	my $rep = $self->{app}{notebook}{name};
+	warn "BUG: no notebook name set!" unless length($rep);
 	my @pages = map "$rep?$_", grep length($_), map {$self->path2page($_)}
 		$self->{tree_view}->get_selection->get_selected_rows;
 	#warn "drag data: @pages";
@@ -132,8 +135,8 @@ sub on_drag_data_received { # we are drag target
 	my $node_ns = ($pos =~ /into/) ? $node.':' : $1;
 	$page =~ /^(.*?)\?(.*:)(.+)/ or return;
 	my ($rep, $ns, $basename) = ($1, $2, $3);
-	if ($rep ne $$self{app}{name} or $ns eq $node_ns) {
-		# either from a different repository
+	if ($rep ne $$self{app}{notebook}{name} or $ns eq $node_ns) {
+		# either from a different notebook
 		# or in the same namespace
 		# => failure
 		$context->finish(0, 1, $time);
@@ -184,6 +187,15 @@ sub on_key_press_event { # some extra keybindings for the treeview
 		my $page = $self->get_selected;
 		$self->{app}->PageView->InsertLink($page, $page, 'NO_ASK');
 	}
+	elsif ($key eq '\\') { # Collapse all
+		$tree_view->collapse_all;
+	}
+	elsif ($key eq '*') { # Expand all
+		$tree_view->expand_all;
+	}
+	elsif ($val == $k_esc) { # Escape - close side pane
+		$$self{app}->TPane(0) if $$self{app}{_pane_visible} == -1;
+	}
 	else { return 0 }
 	return 1;
 }
@@ -205,6 +217,9 @@ sub on_button_release_event {
 
 sub on_row_activated { # load a page when clicked or entered
 	my $self = pop;
+	return if $$self{drag_lock};
+		# Sometimes this signal is triggered while in a drag
+		# operation. Bug in Gtk? Not sure.
 	my ($tree_view, $path) = @_;
 	my $page = $self->path2page($path);
 	$self->{app}->load_page($page)
@@ -314,7 +329,7 @@ sub list_pages {
 	# TODO check for existing children
 	$namespace =~ s/:*$//;
 	my $model = $self->{tree_store};
-	my $repository = $self->{app}{repository};
+	my $notebook = $self->{app}{notebook};
 	my @queue = ([$namespace, $iter]);
 	my $sub = sub {
 		unless (@queue) {
@@ -326,7 +341,7 @@ sub list_pages {
 		my ($ns, $node) = @{ shift @queue };
 		#warn "list_pages: $ns\n";
 		my $child;
-		for my $p ($repository->list_pages($ns)) {
+		for my $p ($notebook->list_pages($ns)) {
 			#warn "\t$p\n";
 			my $is_dir = ($p =~ s/:+$//);
 			my $name = $p;
@@ -344,7 +359,8 @@ sub list_pages {
 		return 1;
 	} ;
 	warn "# Start scanning tree\n";
-	$self->{app}->push_status('Scanning tree ...', 'TreeView');
+	$self->{app}->push_status(
+		__('Scanning tree ...'), 'TreeView'); #. status bar info
 	Glib::Idle->add($sub);
 }
 
@@ -361,26 +377,41 @@ sub list_page {
 	my $model = $self->{tree_view}->get_model;
 	my $iter;
 	my $p = '';
-	while (@page) { # TODO this method assumes case-insensitive sorted namespaces
+	while (@page) {
+		# WARNING this method assumes case-insensitive sorting
 		my $name = shift @page;
 		$p .= ':' . $name;
 		my $child = $model->iter_children($iter);
 			# returns root iter when iter is undef
+
+		# Loop trough children to do case insensitive match.
+		# Stop looping when child is sorting after the name we look for.
 		while ($child and (lc $model->get($child, 1) cmp lc $p) == -1) {
 			$child = $model->iter_next($child);
 		}
 		
 		#warn "list page:\t$p\n";
-		unless ($child) {
+		if (! $child) {
+			# We reached the end of the list when looping,
+			# append item
 			$child = $model->append($iter);
 			$name =~ s/_/ /g;
-			$model->set($child, 0 => $name, 1 => $p); # base_name, name
+			$model->set($child, 0 => $name, 1 => $p);
+				# base_name, name
 		}
 		elsif ((lc $model->get($child, 1) cmp lc $p) == 1) {
+			# We found a child sorting after the one we are
+			# looking for, insert item
 			$child = $model->insert_before(undef, $child);
 			$name =~ s/_/ /g;
-			$model->set($child, 0 => $name, 1 => $p); # base_name, name
+			$model->set($child, 0 => $name, 1 => $p);
+				# base_name, name
 		}
+		# else we found an exact match, do not set properties
+
+		# If the page we are listing was tmp listed before by
+		# select_page, we remove the flag to list it permanently
+		$$self{tmp_listed} = undef if $$self{tmp_listed} eq $p;
 
 		$iter = $child;
 	}
@@ -402,15 +433,31 @@ sub unlist_page {
 	$model->remove($iter);
 }
 
-=item C<select_page(PAGE)>
+=item C<select_page(PAGE, TMP)>
 
 Update the TreeView to display and highlight a certain page.
+If TMP is true the page is temporarily added when it did not yet exist.
 
 =cut
 
 sub select_page {
-	my ($self, $page) = @_;
-	my $path = $self->page2path($page) || return;
+	my ($self, $page, $tmp) = @_;
+	if ($$self{tmp_listed} and $$self{tmp_listed} ne $page) {
+		# Remove a previously temp listed page when changing selection.
+		$self->unlist_page($$self{tmp_listed});
+		$$self{tmp_listed} = undef;
+	}
+
+	my $path = $self->page2path($page);
+	if (! $path && $tmp) {
+		# If page does not exist (or wasn't listed for some reason)
+		# we list it temporarily and select it
+		$self->list_page($page);
+		$$self{tmp_listed} = $page;
+			# do this after list_page(), else it gets deleted
+		$path = $self->page2path($page);
+	}
+	return unless $path;
 	my $view = $self->{tree_view};
 	$view->expand_to_path($path);
 	$view->get_selection->select_path($path);
