@@ -1,6 +1,36 @@
+# Translation of Zim - a desktop wiki.
+# Copyright (C) 2007 Jaap Karssenberg, TRANSLATOR(S)
+# This data is part of a free software application;
+# you can redistribute it and/or modify it under the
+# the same terms as Perl.
 # 
+# 
+# 
+# TRANSLATORS:
+# Balaam's Miracle (nl)
+# Frits Salomons (nl)
+# Jaap Karssenberg (nl)
+# Mathijs (nl)
+# 
+# Project-Id-Version: Zim 0.23
+# Report-Msgid-Bugs-To: 
+# POT-Creation-Date: 2008-08-06 00:10+0200
+# PO-Revision-Date: 2008-08-06 08:07+0000
+# Last-Translator: Jaap Karssenberg <pardus@cpan.org>
+# Language-Team: 
+# MIME-Version: 1.0
+# Content-Type: text/plain; charset=UTF-8
+# Content-Transfer-Encoding: 8bit
+# Plural-Forms: nplurals=2; plural=n != 1;
+# X-Launchpad-Export-Date: 2008-08-21 12:04+0000
+# X-Generator: Launchpad (build Unknown)
+
 use utf8;
 
+# Subroutine to determine plural:
+sub {my $n = shift; $n != 1},
+
+# Hash with translation strings:
 {
   '%a %b %e %Y' => '%a %e %b %Y',
   '<b>Delete page</b>
@@ -10,6 +40,13 @@ page \'{name}\' ?' => '<b>Pagina verwijderen</b>
 
 Weet u zeker dat de pagina
 \'{name}\' wilt verwijderen ?',
+  '<b>Enable Version Control</b>
+
+Version control is currently not enabled for this notebook.
+Do you want to enable it ?' => '<b>Versie beheer inschakelen</b>
+
+Dit notitieboek maakt nog geen gebruik van versie beheer.
+Wilt u versie beheer inschakelen?',
   '<b>Folder does not exist.</b>
 
 The folder: {path}
@@ -25,6 +62,17 @@ Do you want to overwrite it?' => '<b>Pagina bestaat al</b>
 
 De pagina \'{name}\'
 bestaat al. Wilt u deze overschrijven?',
+  '<b>Restore page to saved version?</b>
+
+Do you want to restore page: {page}
+to saved version: {version} ?
+
+All changes since this version will be lost !' => '<b>Opgeslagen versie herstellen?</b>
+
+Wilt u de pagina: {page}
+herstellen naar versie: {version} ?
+
+Alle wijzigingen sinds deze versie zullen verloren gaan!',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -41,6 +89,7 @@ dit resulteert in een aparte hierarchie per maand.
 Wilt u dit notitieboek omzetten naar het nieuwe formaat ?
 ',
   'Add \'tearoff\' strips to the menus' => 'Zet afscheur strips boven de menus',
+  'Application show two text files side by side' => 'Applicatie om twee tekst files te vergelijken',
   'Application to compose email' => 'Programma om email te versturen',
   'Application to edit text files' => 'Programma om tekst files te bewerken',
   'Application to open directories' => 'Programma om mappen te openen',
@@ -48,45 +97,68 @@ Wilt u dit notitieboek omzetten naar het nieuwe formaat ?
   'Attach _File|Attach external file' => 'Bestand _Aanhechten|Bestand aanhechten',
   'Attach external files' => 'Externe bestanden mee kopiëren',
   'Auto-format entities' => 'Auto-format HTML entiteiten',
+  'Auto-increment numbered lists' => 'Automatisch nummers invoegen in lijsten',
   'Auto-link CamelCase' => 'Auto-link CamelCase',
   'Auto-link files' => 'Auto-link bestanden',
+  'Auto-save version on close' => 'Automatisch versie op slaan bij het afsluiten',
   'Auto-select words' => 'Woorden automatisch selecteren',
+  'Automatically increment items in a numbered list' => 'Automatisch nummers invoegen in lijsten waar de regel mt een nummer begint',
   'Automatically link file names when you type' => 'Link bestandsnamen automatisch tijdens het typen',
   'Automaticly link CamelCase words when you type' => 'Link woorden in CamelCase automatisch tijdens het typen',
   'Automaticly select the current word when you toggle the format' => 'Woorden automatisch selecteren wanneer een ander formaat wordt gebruikt',
   'Bold' => 'Vet',
   'Calen_dar|Show calendar' => 'Kalen_der|Kalender tonen',
   'Calendar' => 'Kalender',
+  'Can not save a version without comment' => 'Kan geen versie opslaan zonder omschrijving',
   'Can not save to page: {name}' => 'Kan niet opslaan naar: {name}',
   'Can\'t find {url}' => 'Kan {url} niet vinden',
   'Cha_nge' => '_Wijzigen',
   'Chars' => 'Letters',
   'Check _spelling|Spell check' => '_Spelling controlleren|Spelling controlleren',
   'Choose {app_type}' => 'Kies {app_type}',
+  'Co_mpare Page...' => '_Vergelijk pagina...',
   'Command' => 'Programma',
+  'Compare this version with' => 'Deze versie vergelijken met',
   'Copy Email Address' => 'Email Adres Kopiëren',
   'Copy Location|Copy location' => 'Locatie kopieren|Locatie kopieren',
   'Copy _Link' => '_Link Kopiëren',
   'Could not delete page: {name}' => 'Kan pagina niet verwijderen: {name}',
+  'Could not get annotated source for page {page}' => 'Kan aantekeningen niet vinden voor pagina: {page}',
+  'Could not get changes for page: {page}' => 'Kan geen veranderingen vinden voor pagina: {page}',
+  'Could not get file for page: {page}' => 'Kan geen bestand vinden voor pagina: {page}',
+  'Could not get versions to compare' => 'Kan de versies om te vergelijken niet vinden',
+  'Could not initialize version control' => 'Kan versie beheer niet inschakelen',
   'Could not load page: {name}' => 'Kan pagina niet laden: {name}',
   'Could not rename {from} to {to}' => 'Kan {from} niet hernoemen naar {to}',
   'Could not save page' => 'Kan de pagina niet opslaan',
+  'Could not save version' => 'Versie kan niet opgeslagen worden',
   'Creating a new link directly opens the page' => 'Open de nieuwe pagina direct na het creeëren van de link',
+  'Creation Date' => 'Aanmaakdatum',
   'Cu_t|Cut' => '_Knippen|Knippen',
+  'Current' => 'Huidig',
   'Customise' => 'Wijzigen',
   'Date' => 'Datum',
+  'Default notebook' => 'Standaard notitieboek',
+  'Details' => 'Details',
+  'Diff Editor' => 'Diff applicatie',
+  'Diff editor' => 'Diff applicatie',
   'Directory' => 'Map',
   'Document Root' => 'Bestanden map',
   'E_quation...|Insert equation' => 'Vergelijking...|Vergelijking invoegen',
   'E_xport...|Export' => 'E_xporteren...|Exporteren',
   'E_xternal Link...|Insert external link' => 'E_xterne Link...|Externe link invoegen',
+  'Edit Image' => 'Afbeelding Bewerken',
+  'Edit Link' => 'Link Bewerken',
   'Edit Query' => 'Zoekterm bewerken',
   'Edit _Source|Open source' => 'Brontext Bewerken|Brontext bewerken',
   'Edit notebook' => 'Notitieboek wijzigen',
-  'Edit text files "wiki style"' => 'Bewerk tekst bestanden "wiki style"',
+  'Edit text files "wiki style"' => 'Bewerk tekstbestanden ""wiki style"\'',
   'Editing' => 'Bewerken',
   'Email client' => 'Email programma',
   'Enabled' => 'In gebruik',
+  'Enabling version control will initialize the <b>Bazaar</b> Version Control System.
+Please click \'help\' to read about the system requirements and alternatives.' => 'Versie beheer maakt gebruik van het <b>Bazaar</b> Version Control System.
+Klik op \'hulp\' om de systeem eisen en alternatieven te bekijken.',
   'Equation Editor' => 'Formule Bewerken',
   'Equation Editor Log' => 'Formule Log',
   'Expand side pane' => 'Zij-paneel uitklappen',
@@ -96,12 +168,14 @@ Wilt u dit notitieboek omzetten naar het nieuwe formaat ?
   'File browser' => 'Bestandsbrowser',
   'File is not a text file: {file}' => 'Bestand is geen tekst bestand: {file}',
   'Filter' => 'Filter',
+  'Find' => 'Zoek',
   'Find Ne_xt|Find next' => 'Vindt _Volgende|Vindt volgende',
   'Find Pre_vious|Find previous' => 'Vindt Vor_ige|Vindt vorige',
   'Find and Replace' => 'Zoeken en vervange',
   'Find what' => 'Zoek deze',
   'Follow new link' => 'Nieuwe links volgen',
   'For_mat|' => '_Opmaak',
+  'Format' => 'Opmaak',
   'General' => 'Algemeen',
   'Go to "{link}"' => 'Ga naar "{link}"',
   'H_idden|.' => '_Verbergen',
@@ -118,7 +192,9 @@ Wilt u dit notitieboek omzetten naar het nieuwe formaat ?
   'Height' => 'Hoogte',
   'Home Page' => 'Start Pagina',
   'Icon' => 'Icoon',
+  'Id' => 'Id',
   'Index page' => 'Index pagina',
+  'Initial version' => 'Eerste versie',
   'Insert Date' => 'Datum invoegen',
   'Insert Image' => 'Afbeelding invoegen',
   'Insert Link' => 'Link invoegen',
@@ -131,12 +207,14 @@ Wilt u dit notitieboek omzetten naar het nieuwe formaat ?
   'Links to' => 'Link naar',
   'Match c_ase' => 'Hoofdletter gevoelig',
   'Media' => 'Bestanden',
+  'Modification Date' => 'Wijzigingsdatum',
   'Name' => 'Naam',
   'New notebook' => 'Nieuw notitieboek',
   'New page' => 'Nieuwe pagina',
   'No such directory: {name}' => 'Map bestaat niet: {name}',
   'No such file: {file}' => 'Bestand niet gevonden: {file}',
   'No such notebook: {name}' => 'Notitieboek niet gevonden: {name}',
+  'No such page: {page}' => 'Pagina bestaat niet: {page}',
   'No such plugin: {name}' => 'Plugin niet gevonden: {name}',
   'Normal' => 'Normaal',
   'Not Now' => 'Niet Nu',
@@ -153,23 +231,28 @@ kan u ook een nieuwe pagina aanmaken.',
   'Open notebook' => 'Notitieboek openen',
   'Other...' => 'Overige...',
   'Output' => 'Formaat',
+  'Output dir' => 'Map',
   'P_athbar type|' => 'Locatiebalk',
   'Page' => 'Pagina',
-  'Page Editable|Page editable' => 'Pagina wijzigbaar|Pagina wijzigbaar',
+  'Page Editable|Page editable' => 'Pagina te wijzigen|Pagina te wijzigen',
   'Page name' => 'Pagina naam',
   'Pages' => 'Paginas',
+  'Please enter a comment for this version' => 'Geef een korte omschrijving voor deze versie',
+  'Please enter a name to save a copy of page: {page}' => 'Geef een naam op om een kopie op te slaan van: {page}',
   'Please enter a {app_type}' => 'Geef een commando om een {app_type} te starten',
+  'Please give a page first' => 'Geef eerst een pagina op',
   'Please give at least a directory to store your pages.
 For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'U dient een map aan te geven om uw notities op te slaan.
 Voor een nieuw notitieboek dien dit een lege map te zijn.
 Bijvoorbeeld een map "Notes" in uw persoonlijke map.',
-  'Please select a default notebook here' => 'Selecteer uw standaard notitieboek',
+  'Please select a notebook first' => 'Selecteer eerst een notitieboek',
+  'Please select a version first' => 'Geef eerst een versie op',
   'Plugin already loaded: {name}' => 'Plugin is al geladen: {name}',
   'Plugins' => 'Plugins',
   'Pr_eferences|Preferences dialog' => '_Voorkeuren|Voorkeuren wijzigen',
   'Preferences' => 'Voorkeuren',
-  'Prefix document root' => 'Prefix documenten root',
+  'Prefix document root' => 'Voorvoegsel documentenroot',
   'Print to Browser|Print to browser' => 'Print naar Browser|Print naar browser',
   'Prio' => 'Prio',
   'Proper_ties|Properties dialog' => 'Ei_genschappen...|Eigenschappen',
@@ -181,25 +264,27 @@ Bijvoorbeeld een map "Notes" in uw persoonlijke map.',
   'Rename to' => 'Hernoemen naar',
   'Replace _all' => '_Alles vervangen',
   'Replace with' => 'Vervangen door',
-  'S_ave A Copy...|Save a copy' => 'Ko_pie Opslaan...|Kopie opslaan',
+  'S_ave Version...|Save Version' => 'V_ersie Opslaan...|Versie opslaan',
   'Save Copy' => 'Kopie Opslaan',
+  'Save version' => 'Versie opslaan',
   'Scanning tree ...' => 'Index aan het opbouwen ...',
   'Search' => 'Zoeken',
   'Search _Backlinks...|Search Back links' => 'Zoek Verwijzingen|Zoek verwijzingen',
   'Select File' => 'Bestand selecteren',
+  'Select Folder' => 'Selecteer Map',
   'Send To...' => 'Zenden naar...',
-  'Set _Default' => 'Standaard instellen',
-  'Set default notebook' => 'Standaard notitieboek instellen',
   'Show cursor for read-only' => 'Laat cursor zien in read-only mode',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Laat de cursor zien ook wanneer de pagina niet gewijzigd kan worden.Dit is nuttig voor navigatie met het toetsenbord',
   'Slow file system' => 'Langzaam bestands systeen',
   'Source' => 'Bron',
+  'Source Format' => 'Bronformaat',
   'Start the side pane with the whole tree expanded.' => 'Start met alle items in het zij-paneel uitgeklapt.',
   'Stri_ke|Strike' => '_Doorhalen|Doorhalen',
   'Strike' => 'Doorgehaald',
   'TODO List' => 'Taken lijst',
   'Task' => 'Taak',
   'Tearoff menus' => 'Afscheurbare menus',
+  'Template' => 'Template',
   'Text' => 'Tekst',
   'Text Editor' => 'Tekst Verwerker',
   'Text _From File...|Insert text from file' => 'Tekst Uit _Bestand|Tekst uit bestand invoegen',
@@ -208,7 +293,7 @@ Bijvoorbeeld een map "Notes" in uw persoonlijke map.',
   'The equation for image: {path}
 is missing. Can not edit equation.' => 'De formule voor het bestand: {path}
 mist. Kan de formule niet wijzigen.',
-  'This notebook does not have a document root' => 'Dit notitieboek heeft geen documenten root.',
+  'This notebook does not have a document root' => 'Dit notitieboek heeft geen documentenroot.',
   'This page does not exist
 404' => 'Deze pagina bestaat niet
 404',
@@ -227,8 +312,11 @@ mist. Kan de formule niet wijzigen.',
   'Use the "Backspace" key to un-indent bullet lists (Same as "Shift-Tab")' => 'Gebruik de "Backspace" toets om het inspringen van een aantal regelsongedaan te maken. (Gelijk aan "Shift-Tab")',
   'Use the "Ctrl-Space" key combo to switch focus between text and side pane. If disabled you can still use "Alt-Space".' => 'Gebruik de "Ctrl-Spatie" toetsen combinatie om focus te switchen tusse detekst en het zij-paneel. Als deze optie uitstaat kunt u nog steeds"Alt-Spatie" gebruiken.',
   'Use the "Enter" key to follow links. If disabled you still can use "Alt-Enter"' => 'Gebruik de "Enter" toets om links te volgen. Wanneer deze optie uit staatkunt u nog steeds "Alt-Enter" gebruiken voor navigatie"',
+  'User' => 'Gebruiker',
   'User name' => 'Gebruiker naam',
   'Verbatim' => 'Letterlijk',
+  'Versions' => 'Versies',
+  'View _Annotated...' => 'Bekijk _Aantekeningen...',
   'View _Log' => 'Bekijk _Log',
   'Web browser' => 'Webbrowser',
   'Whole _word' => 'Hele woord',
@@ -251,6 +339,7 @@ voordat nieuwe plugins geladen worden.',
   '_Child|Go to child page' => 'Om_laag|Ga pagina omlaag',
   '_Close|Close window' => 'Sl_uiten|Window sluiten',
   '_Contents|Help contents' => 'I_nhoud|Hulp inhoud',
+  '_Copy Page...|Copy page' => 'Pagina _Kopiëren|Pagina kopiëren',
   '_Copy|Copy' => 'K_opiëren|Kopiëren',
   '_Date and Time...|Insert date' => '_Datum en Tijd|Datum en tijd invoegen',
   '_Delete Page|Delete page' => 'Pagina Verwijderen|Pagina verwijderen',
@@ -285,10 +374,12 @@ voordat nieuwe plugins geladen worden.',
   '_Next' => 'V_olgende',
   '_Next in index|Go to next page' => 'Vo_lgende in de index|Ga naar de volgende pagina',
   '_Normal|Normal' => '_Normaal|Normaal',
-  '_Open Another Notebook...|Open notebook' => '_Open ander notitieboek',
+  '_Notebook Changes...' => 'Veranderingen _Notitieboek...',
+  '_Open Another Notebook...|Open notebook' => '_Open ander notitieboek...|Open notitieboek',
   '_Open link' => '_Open link',
   '_Overwrite' => '_Overschrijven',
   '_Page' => '_Pagina',
+  '_Page Changes...' => 'Veranderingen _Pagina...',
   '_Parent|Go to parent page' => '_Omhoog|Ga pagina omhoog',
   '_Paste|Paste' => '_Plakken|Plakken',
   '_Preview' => '_Tonen',
@@ -304,10 +395,11 @@ voordat nieuwe plugins geladen worden.',
   '_Replace' => '_Vervangen',
   '_Replace...|Find and Replace' => '_Vervangen...|Zoeken en vervangen',
   '_Reset' => '_Herstellen',
+  '_Restore Version...' => 'Versie _Herstellen...',
   '_Save Copy' => 'Kopie _Opslaan',
   '_Save a copy...' => '_Kopie opslaan...',
   '_Save|Save page' => '_Opslaan|Pagina opslaan',
-  '_Screenshot...|Insert screenshot' => '_Screenshot...|Screenshot invoegen',
+  '_Screenshot...|Insert screenshot' => '_Schermafdruk...|Schermafdruk invoegen',
   '_Search...|Search' => '_Zoeken...|zoeken',
   '_Search|' => '_Zoeken',
   '_Send To...|Mail page' => '_Versturen...|Pagina versturen',
@@ -319,13 +411,22 @@ voordat nieuwe plugins geladen worden.',
   '_Underline|Underline' => '_Oderstrepen|Onderstrepen',
   '_Undo|Undo' => '_Ongedaan maken|Ongedaan maken',
   '_Update links in this page' => 'Links in deze pagina _aanpassen',
-  '_Update {number} pages linking here' => '{number} links naar deze pagina _aanpassen',
+  '_Update {number} page linking here' => [
+    '{number} link naar deze pagina aanpassen',
+    '{number} links naar deze pagina aanpassen'
+  ],
   '_Verbatim|Verbatim' => '_Letterlijk|Letterlijk',
+  '_Versions...|Versions' => '_Versies...|Versies',
   '_View|' => 'Beel_d',
   '_Word Count|Word count' => '_Woorden Tellen|Woorden tellen',
   'other...' => 'anders...',
-  'translator-credits' => 'Launchpad Contributions:
-  Jaap Karssenberg https://launchpad.net/~pardus-cpan',
-  '{number} _Back links' => '{number} _Referenties',
-  '{total} items total' => '{total} taken'
+  '{name}_(Copy)' => '{name}_(Kopie)',
+  '{number} _Back link' => [
+    '{number} _Referentie',
+    '{number} _Referenties'
+  ],
+  '{number} item total' => [
+    '{number} taak',
+    '{number} taken'
+  ]
 };
